@@ -93,7 +93,7 @@ def get_trainer(config,
                                     save_best_only=True, 
                                     round_values_on_print_to=7), 
                     Tensorboard(summary_writer_dir=summary_writer_dir),
-                    EarlyStopping(apply_on_phase=Phase.EPOCH_END, apply_on_states=State.VAL, patience=config.EARLY_STOPPING_PATIENCE),
+                    EarlyStopping(apply_on_phase=Phase.EPOCH_END, apply_on_states=State.EXTERNAL, patience=config.EARLY_STOPPING_PATIENCE),
                     StatsPrint(apply_on_phase=Phase.EPOCH_END, round_values_on_print_to=7, metric_names=metric_name_to_func.keys()) # BETTER TO PUT StatsPrint LAST (MAKES BETTER SENSE IN THE LOG PRINTS)
                 ]
 
